@@ -10,6 +10,8 @@ check() {
 	    mkfs.xfs \
 	    xfs_admin \
 	    xfs_growfs \
+	    xfs_db \
+	    udevadm \
 	    plymouth \
 	    /usr/sbin/plymouthd \
 	    /usr/lib/udev/stratis-str-cmp \
@@ -39,6 +41,8 @@ install() {
 	    mkfs.xfs \
 	    xfs_admin \
 	    xfs_growfs \
+	    xfs_db \
+	    udevadm \
 	    plymouth \
 	    /usr/sbin/plymouthd \
 	    /usr/lib/udev/stratis-str-cmp
